@@ -147,6 +147,31 @@ class table__n_a_m_e(DefaultTable.DefaultTable):
 		else:
 			self.names.append(makeName(string, nameID, platformID, platEncID, langID))
 
+	def removeNames(self, nameID=None, platformID=None, platEncID=None, langID=None):
+		"""Remove any name records identified by the given combination of 'nameID',
+		'platformID', 'platEncID' and 'langID'.
+		"""
+		args = {
+			argName: argValue
+			for argName, argValue in (
+				("nameID", nameID),
+				("platformID", platformID),
+				("platEncID", platEncID),
+				("langID", langID),
+			)
+			if argValue is not None
+		}
+		if not args:
+			# no arguments, nothing to do
+			return
+		self.names = [
+			rec for rec in self.names
+			if any(
+				argValue != getattr(rec, argName)
+				for argName, argValue in args.items()
+			)
+		]
+
 	def _findUnusedNameID(self, minNameID=256):
 		"""Finds an unused name id.
 
@@ -390,13 +415,7 @@ class NameRecord(object):
 		"""
 		return tobytes(self.string, encoding=self.getEncoding(), errors=errors)
 
-	def toStr(self, errors='strict'):
-		if str == bytes:
-			# python 2
-			return self.toBytes(errors)
-		else:
-			# python 3
-			return self.toUnicode(errors)
+	toStr = toUnicode
 
 	def toXML(self, writer, ttFont):
 		try:
